@@ -26,7 +26,6 @@ from platformio.util import strip_ansi_codes
 
 
 class UnityTestRunner(TestRunnerBase):
-
     EXTRA_LIB_DEPS = ["throwtheswitch/Unity@^2.5.2"]
 
     # Examples:
@@ -56,8 +55,8 @@ extern "C"
 
 void unityOutputStart(unsigned long);
 void unityOutputChar(unsigned int);
-void unityOutputFlush();
-void unityOutputComplete();
+void unityOutputFlush(void);
+void unityOutputComplete(void);
 
 #define UNITY_OUTPUT_START()    unityOutputStart((unsigned long) $baudrate)
 #define UNITY_OUTPUT_CHAR(c)    unityOutputChar(c)
@@ -115,7 +114,7 @@ $framework_config_code
         native=dict(
             code="""
 #include <stdio.h>
-void unityOutputStart(unsigned long baudrate) { }
+void unityOutputStart(unsigned long baudrate) { (void) baudrate; }
 void unityOutputChar(unsigned int c) { putchar(c); }
 void unityOutputFlush(void) { fflush(stdout); }
 void unityOutputComplete(void) { }
@@ -156,7 +155,7 @@ void unityOutputComplete(void) { }
         espidf=dict(
             code="""
 #include <stdio.h>
-void unityOutputStart(unsigned long baudrate) { }
+void unityOutputStart(unsigned long baudrate) { (void) baudrate; }
 void unityOutputChar(unsigned int c) { putchar(c); }
 void unityOutputFlush(void) { fflush(stdout); }
 void unityOutputComplete(void) { }
@@ -166,7 +165,7 @@ void unityOutputComplete(void) { }
         zephyr=dict(
             code="""
 #include <sys/printk.h>
-void unityOutputStart(unsigned long baudrate) { }
+void unityOutputStart(unsigned long baudrate) { (void) baudrate; }
 void unityOutputChar(unsigned int c) { printk("%c", c); }
 void unityOutputFlush(void) { }
 void unityOutputComplete(void) { }
@@ -247,18 +246,20 @@ void unityOutputComplete(void) { unittest_uart_end(); }
         unity_h = dst_dir / "unity_config.h"
         if not unity_h.is_file():
             unity_h.write_text(
-                string.Template(self.UNITY_CONFIG_H).substitute(
-                    baudrate=self.get_test_speed()
-                ),
+                string.Template(self.UNITY_CONFIG_H)
+                .substitute(baudrate=self.get_test_speed())
+                .strip()
+                + "\n",
                 encoding="utf8",
             )
         framework_config = self.get_unity_framework_config()
         unity_c = dst_dir / ("unity_config.%s" % framework_config.get("language", "c"))
         if not unity_c.is_file():
             unity_c.write_text(
-                string.Template(self.UNITY_CONFIG_C).substitute(
-                    framework_config_code=framework_config["code"]
-                ),
+                string.Template(self.UNITY_CONFIG_C)
+                .substitute(framework_config_code=framework_config["code"])
+                .strip()
+                + "\n",
                 encoding="utf8",
             )
 
