@@ -15,7 +15,7 @@
 from os.path import isfile, join
 
 from platformio.commands.ci import cli as cmd_ci
-from platformio.commands.lib.command import cli as cmd_lib
+from platformio.package.commands.install import package_install_cmd
 
 
 def test_ci_empty(clirunner):
@@ -88,6 +88,70 @@ def test_ci_keep_build_dir(clirunner, tmpdir_factory, validate_cliresult):
     assert "board: metro" in result.output
 
 
+def test_ci_keep_build_dir_single_src_dir(
+    clirunner, tmpdir_factory, validate_cliresult
+):
+    build_dir = str(tmpdir_factory.mktemp("ci_build_dir"))
+
+    # Run two times to detect possible "AlreadyExists" errors
+    for _ in range(2):
+        result = clirunner.invoke(
+            cmd_ci,
+            [
+                join("examples", "wiring-blink", "src"),
+                "-b",
+                "uno",
+                "--build-dir",
+                build_dir,
+                "--keep-build-dir",
+            ],
+        )
+        validate_cliresult(result)
+
+
+def test_ci_keep_build_dir_nested_src_dirs(
+    clirunner, tmpdir_factory, validate_cliresult
+):
+    build_dir = str(tmpdir_factory.mktemp("ci_build_dir"))
+
+    # Split default Arduino project in two parts
+    src_dir1 = tmpdir_factory.mktemp("src_1")
+    src_dir1.join("src1.cpp").write(
+        """
+#include <Arduino.h>
+void setup() {}
+"""
+    )
+
+    src_dir2 = tmpdir_factory.mktemp("src_2")
+    src_dir2.join("src2.cpp").write(
+        """
+#include <Arduino.h>
+void loop() {}
+"""
+    )
+
+    src_dir1 = str(src_dir1)
+    src_dir2 = str(src_dir2)
+
+    # Run two times to detect possible "AlreadyExists" errors
+    for _ in range(2):
+        result = clirunner.invoke(
+            cmd_ci,
+            [
+                src_dir1,
+                src_dir2,
+                "-b",
+                "teensy40",
+                "--build-dir",
+                build_dir,
+                "--keep-build-dir",
+            ],
+        )
+
+        validate_cliresult(result)
+
+
 def test_ci_project_conf(clirunner, validate_cliresult):
     project_dir = join("examples", "wiring-blink")
     result = clirunner.invoke(
@@ -105,7 +169,8 @@ def test_ci_project_conf(clirunner, validate_cliresult):
 def test_ci_lib_and_board(clirunner, tmpdir_factory, validate_cliresult):
     storage_dir = str(tmpdir_factory.mktemp("lib"))
     result = clirunner.invoke(
-        cmd_lib, ["--storage-dir", storage_dir, "install", "1@2.3.2"]
+        package_install_cmd,
+        ["--global", "--storage-dir", storage_dir, "--library", "1"],
     )
     validate_cliresult(result)
 
@@ -117,7 +182,7 @@ def test_ci_lib_and_board(clirunner, tmpdir_factory, validate_cliresult):
                 "OneWire",
                 "examples",
                 "DS2408_Switch",
-                "DS2408_Switch.pde",
+                "DS2408_Switch.ino",
             ),
             "-l",
             join(storage_dir, "OneWire"),
