@@ -19,7 +19,7 @@ import tarfile
 import jsondiff
 import pytest
 
-from platformio.compat import WINDOWS
+from platformio.compat import IS_WINDOWS
 from platformio.package.manifest import parser
 from platformio.package.manifest.schema import ManifestSchema, ManifestValidationError
 
@@ -28,7 +28,8 @@ def test_library_json_parser():
     contents = """
 {
     "name": "TestPackage",
-    "keywords": "kw1, KW2, kw3",
+    "keywords": "kw1, KW2, kw3, KW2, kw 4, kw_5, kw-6",
+    "headers": "include1.h, Include2.hpp",
     "platforms": ["atmelavr", "espressif"],
     "repository": {
         "type": "git",
@@ -44,7 +45,7 @@ def test_library_json_parser():
     "dependencies": {
         "deps1": "1.2.0",
         "deps2": "https://github.com/username/package.git",
-        "@owner/deps3": "^2.1.3"
+        "owner/deps3": "^2.1.3"
     },
     "customField": "Custom Value"
 }
@@ -61,13 +62,14 @@ def test_library_json_parser():
                 "url": "https://github.com/username/repo.git",
             },
             "export": {"exclude": [".gitignore", "tests"], "include": ["mylib"]},
-            "keywords": ["kw1", "kw2", "kw3"],
+            "keywords": ["kw1", "kw2", "kw3", "kw 4", "kw_5", "kw-6"],
+            "headers": ["include1.h", "Include2.hpp"],
             "homepage": "http://old.url.format",
             "build": {"flags": ["-DHELLO"]},
             "dependencies": [
-                {"name": "@owner/deps3", "version": "^2.1.3"},
                 {"name": "deps1", "version": "1.2.0"},
                 {"name": "deps2", "version": "https://github.com/username/package.git"},
+                {"owner": "owner", "name": "deps3", "version": "^2.1.3"},
             ],
             "customField": "Custom Value",
         },
@@ -76,14 +78,14 @@ def test_library_json_parser():
     contents = """
 {
     "keywords": ["sound", "audio", "music", "SD", "card", "playback"],
+    "headers": ["include 1.h", "include Space.hpp"],
     "frameworks": "arduino",
-    "platforms": "atmelavr",
     "export": {
         "exclude": "audio_samples"
     },
     "dependencies": [
         {"name": "deps1", "version": "1.0.0"},
-        {"name": "@owner/deps2", "version": "1.0.0", "platforms": "*", "frameworks": "arduino, espidf"},
+        {"owner": "owner", "name": "deps2", "version": "1.0.0", "platforms": "*", "frameworks": "arduino, espidf"},
         {"name": "deps3", "version": "1.0.0", "platforms": ["ststm32", "sifive"]}
     ]
 }
@@ -94,17 +96,18 @@ def test_library_json_parser():
         raw_data,
         {
             "keywords": ["sound", "audio", "music", "sd", "card", "playback"],
+            "headers": ["include 1.h", "include Space.hpp"],
             "frameworks": ["arduino"],
             "export": {"exclude": ["audio_samples"]},
-            "platforms": ["atmelavr"],
             "dependencies": [
+                {"name": "deps1", "version": "1.0.0"},
                 {
-                    "name": "@owner/deps2",
+                    "owner": "owner",
+                    "name": "deps2",
                     "version": "1.0.0",
                     "platforms": ["*"],
                     "frameworks": ["arduino", "espidf"],
                 },
-                {"name": "deps1", "version": "1.0.0"},
                 {
                     "name": "deps3",
                     "version": "1.0.0",
@@ -115,16 +118,16 @@ def test_library_json_parser():
     )
 
     raw_data = parser.LibraryJsonManifestParser(
-        '{"dependencies": ["dep1", "dep2", "@owner/dep3"]}'
+        '{"dependencies": ["dep1", "dep2", "owner/dep3@1.2.3"]}'
     ).as_dict()
     raw_data["dependencies"] = sorted(raw_data["dependencies"], key=lambda a: a["name"])
     assert not jsondiff.diff(
         raw_data,
         {
             "dependencies": [
-                {"name": "@owner/dep3"},
                 {"name": "dep1"},
                 {"name": "dep2"},
+                {"name": "owner/dep3@1.2.3"},
             ],
         },
     )
@@ -201,9 +204,11 @@ version=1.2.3
 author=SomeAuthor <info AT author.com>, Maintainer Author (nickname) <www.example.com>
 maintainer=Maintainer Author (nickname) <www.example.com>
 sentence=This is Arduino library
+category=Signal Input/Output
 customField=Custom Value
 depends=First Library (=2.0.0), Second Library (>=1.2.0), Third
 ignore_empty_field=
+includes=Arduino.h, Arduino Space.hpp
 """
     raw_data = parser.LibraryPropertiesManifestParser(contents).as_dict()
     raw_data["dependencies"] = sorted(raw_data["dependencies"], key=lambda a: a["name"])
@@ -214,16 +219,15 @@ ignore_empty_field=
             "version": "1.2.3",
             "description": "This is Arduino library",
             "sentence": "This is Arduino library",
-            "platforms": ["*"],
             "frameworks": ["arduino"],
-            "export": {
-                "exclude": ["extras", "docs", "tests", "test", "*.doxyfile", "*.pdf"]
-            },
             "authors": [
                 {"name": "SomeAuthor", "email": "info@author.com"},
                 {"name": "Maintainer Author", "maintainer": True},
             ],
-            "keywords": ["uncategorized"],
+            "category": "Signal Input/Output",
+            "keywords": ["signal", "input", "output"],
+            "headers": ["Arduino.h", "Arduino Space.hpp"],
+            "includes": "Arduino.h, Arduino Space.hpp",
             "customField": "Custom Value",
             "depends": "First Library (=2.0.0), Second Library (>=1.2.0), Third",
             "dependencies": [
@@ -263,7 +267,6 @@ ignore_empty_field=
         ),
     ).as_dict()
     assert data["export"] == {
-        "exclude": ["extras", "docs", "tests", "test", "*.doxyfile", "*.pdf"],
         "include": ["libraries/TestPackage"],
     }
     assert data["repository"] == {
@@ -290,6 +293,7 @@ maintainer=Rocket Scream Electronics
     assert data["authors"] == [
         {"name": "Rocket Scream Electronics", "maintainer": True}
     ]
+    assert "keywords" not in data
 
 
 def test_library_json_schema():
@@ -318,6 +322,9 @@ def test_library_json_schema():
   "frameworks": "arduino",
   "platforms": "*",
   "license": "MIT",
+  "scripts": {
+      "postinstall": "script.py"
+  },
   "examples": [
     {
         "name": "JsonConfigFile",
@@ -368,6 +375,7 @@ def test_library_json_schema():
             "frameworks": ["arduino"],
             "platforms": ["*"],
             "license": "MIT",
+            "scripts": {"postinstall": "script.py"},
             "examples": [
                 {
                     "name": "JsonConfigFile",
@@ -422,6 +430,25 @@ def test_library_json_schema():
         },
     )
 
+    # test multiple licenses
+    contents = """
+{
+    "name": "MultiLicense",
+    "version": "1.0.0",
+    "license": "MIT AND (LGPL-2.1-or-later OR BSD-3-Clause)"
+}
+"""
+    raw_data = parser.LibraryJsonManifestParser(contents).as_dict()
+    data = ManifestSchema().load_manifest(raw_data)
+    assert not jsondiff.diff(
+        data,
+        {
+            "name": "MultiLicense",
+            "version": "1.0.0",
+            "license": "MIT AND (LGPL-2.1-or-later OR BSD-3-Clause)",
+        },
+    )
+
 
 def test_library_properties_schema():
     contents = """
@@ -433,7 +460,7 @@ sentence=A library for monochrome TFTs and OLEDs
 paragraph=Supported display controller: SSD1306, SSD1309, SSD1322, SSD1325
 category=Display
 url=https://github.com/olikraus/u8glib
-architectures=avr,sam
+architectures=avr,sam,samd
 depends=First Library (=2.0.0), Second Library (>=1.2.0), Third
 """
     raw_data = parser.ManifestParserFactory.new(
@@ -457,9 +484,6 @@ depends=First Library (=2.0.0), Second Library (>=1.2.0), Third
             "frameworks": ["arduino"],
             "platforms": ["atmelavr", "atmelsam"],
             "version": "1.19.1",
-            "export": {
-                "exclude": ["extras", "docs", "tests", "test", "*.doxyfile", "*.pdf"]
-            },
             "authors": [
                 {"maintainer": True, "email": "olikraus@gmail.com", "name": "oliver"}
             ],
@@ -507,9 +531,9 @@ includes=MozziGuts.h
     errors = None
     try:
         ManifestSchema().load_manifest(raw_data)
-    except ManifestValidationError as e:
-        data = e.valid_data
-        errors = e.messages
+    except ManifestValidationError as exc:
+        data = exc.valid_data
+        errors = exc.messages
 
     assert errors["authors"]
 
@@ -529,9 +553,7 @@ includes=MozziGuts.h
             },
             "platforms": ["*"],
             "frameworks": ["arduino"],
-            "export": {
-                "exclude": ["extras", "docs", "tests", "test", "*.doxyfile", "*.pdf"]
-            },
+            "headers": ["MozziGuts.h"],
             "authors": [
                 {
                     "maintainer": True,
@@ -551,7 +573,7 @@ def test_platform_json_schema():
   "name": "atmelavr",
   "title": "Atmel AVR",
   "description": "Atmel AVR 8- and 32-bit MCUs deliver a unique combination of performance, power efficiency and design flexibility. Optimized to speed time to market-and easily adapt to new ones-they are based on the industrys most code-efficient architecture for C and assembly programming.",
-  "keywords": "arduino, atmel, avr",
+  "keywords": "arduino, atmel, avr, MCU",
   "homepage": "http://www.atmel.com/products/microcontrollers/avr/default.aspx",
   "license": "Apache-2.0",
   "engines": {
@@ -575,6 +597,7 @@ def test_platform_json_schema():
   "packages": {
     "toolchain-atmelavr": {
       "type": "toolchain",
+      "owner": "platformio",
       "version": "~1.50400.0"
     },
     "framework-arduinoavr": {
@@ -610,7 +633,7 @@ def test_platform_json_schema():
                 "on the industrys most code-efficient architecture for C and "
                 "assembly programming."
             ),
-            "keywords": ["arduino", "atmel", "avr"],
+            "keywords": ["arduino", "atmel", "avr", "mcu"],
             "homepage": "http://www.atmel.com/products/microcontrollers/avr/default.aspx",
             "license": "Apache-2.0",
             "repository": {
@@ -622,7 +645,11 @@ def test_platform_json_schema():
             "dependencies": [
                 {"name": "framework-arduinoavr", "version": "~4.2.0"},
                 {"name": "tool-avrdude", "version": "~1.60300.0"},
-                {"name": "toolchain-atmelavr", "version": "~1.50400.0"},
+                {
+                    "name": "toolchain-atmelavr",
+                    "owner": "platformio",
+                    "version": "~1.50400.0",
+                },
             ],
         },
     )
@@ -635,7 +662,7 @@ def test_package_json_schema():
     "description": "SCons software construction tool",
     "keywords": "SCons, build",
     "homepage": "http://www.scons.org",
-    "system": ["linux_armv6l", "linux_armv7l", "linux_armv8l"],
+    "system": ["linux_armv6l", "linux_armv7l", "linux_armv8l", "LINUX_ARMV7L"],
     "version": "3.30101.0"
 }
 """
@@ -714,7 +741,7 @@ def test_examples_from_dir(tmpdir_factory):
     pio_dir.join(".vimrc").write("")
     pio_ini = pio_dir.join("platformio.ini")
     pio_ini.write("")
-    if not WINDOWS:
+    if not IS_WINDOWS:
         pio_dir.join("platformio.ini.copy").mksymlinkto(pio_ini)
     pio_dir.mkdir("include").join("main.h").write("")
     pio_dir.mkdir("src").join("main.cpp").write("")
@@ -855,6 +882,11 @@ def test_broken_schemas():
         ManifestValidationError, match=("Invalid semantic versioning format")
     ):
         ManifestSchema().load_manifest(dict(name="MyPackage", version="broken_version"))
+    # version with leading zeros
+    with pytest.raises(
+        ManifestValidationError, match=("Invalid semantic versioning format")
+    ):
+        ManifestSchema().load_manifest(dict(name="MyPackage", version="01.02.00"))
 
     # broken value for Nested
     with pytest.raises(ManifestValidationError, match=r"authors.*Invalid input type"):
@@ -869,5 +901,5 @@ def test_broken_schemas():
         )
 
     # invalid package name
-    with pytest.raises(ManifestValidationError, match=("are not allowed")):
+    with pytest.raises(ManifestValidationError, match="are not allowed"):
         ManifestSchema().load_manifest(dict(name="C/C++ :library", version="1.2.3"))
